pub struct OverlayPlugin {
    pub font: Option<&'static str>,
    pub fallback_color: Color,
    pub font_size: f32,
}
The text overlay plugin, you must add this plugin for the screen_print! macro to work. You must also spawn a UiCameraBundle.

You can manage some of the text properties by setting the fields of the plugin.

Fields

font: Option<&'static str>

The font to use, by default it is a variant of adobe’s SourcePro only containing ascii characters.

If the builtin-font flag is disabled, you must set this to Some(thing), otherwise the plugin will panic at initialization.

You can provide your own font by setting this to Some("path/to/font.ttf").

fallback_color: Color

The color to use when none are specified in screen_print!, by default it is yellow.

font_size: f32

The size of the message to display on screen, by default it is 13.0